eliot-dev
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Eliot-dev] Changes to eliot/game/player.h


From: eliot-dev
Subject: [Eliot-dev] Changes to eliot/game/player.h
Date: Sat, 05 Nov 2005 18:57:43 -0500

Index: eliot/game/player.h
diff -u eliot/game/player.h:1.8 eliot/game/player.h:1.9
--- eliot/game/player.h:1.8     Fri Nov  4 20:00:06 2005
+++ eliot/game/player.h Sat Nov  5 23:57:41 2005
@@ -21,11 +21,9 @@
 #define _PLAYER_H_
 
 #include <vector>
+#include "pldrack.h"
 
-class Playedrack;
 class Round;
-class Board;
-typedef struct _Dictionary * Dictionary;
 
 
 /**
@@ -66,10 +64,13 @@
     void endTurn(const Round &iRound, int iTurn);
 
 private:
-    // Score of the player
+    /// Score of the player
     int m_score;
 
-    // History of the racks and rounds for the player
+    /// Current played rack of the player
+    PlayedRack m_pldrack;
+
+    /// History of the racks and rounds for the player
     vector<PlayedRack *> m_playedRacks;
     vector<Round *> m_rounds;
     vector<int> m_turns;




reply via email to

[Prev in Thread] Current Thread [Next in Thread]